<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:adf="urn:avicomsys-ru:adf-preview">
  <xsl:variable name="lang" select="adf:GetLanguage()" />
	<xsl:template match="/">
		<HTML>
			<HEAD>
				<TITLE>
					<xsl:value-of select="pjm5ExpenseGet/Expense/FileAs" />
				</TITLE>
				<xsl:value-of select="adf:GetCss()" disable-output-escaping="yes" />
			</HEAD>
			<BODY >
				<xsl:value-of select="adf:GetHeader(pjm5ExpenseGet/Expense)"  disable-output-escaping="yes"/>
				<xsl:apply-templates select="pjm5ExpenseGet/Expense"/>
				<xsl:value-of select="adf:GetFooter(pjm5ExpenseGet/Expense)"  disable-output-escaping="yes"/>
			</BODY>
		</HTML>
	</xsl:template>


	<xsl:template match="Expense">
		<xsl:variable name="price" select="Price"></xsl:variable>
		<xsl:variable name="vat" select="VAT"></xsl:variable>
		<xsl:variable name="vatr" select="VATRate"></xsl:variable>
		<xsl:variable name="amount" select="Amount"></xsl:variable>
		<xsl:variable name="cur" select="FromCurrencyCode"></xsl:variable>
		<xsl:variable name="bcur" select="ToCurrencyCode"></xsl:variable>
		<xsl:variable name="ncur" select="NationalCurrencyCode"></xsl:variable>
		<xsl:variable name="cr1" select="CurrencyRate"></xsl:variable>

		<table style="font-family:Verdana;font-size:8pt" cellspacing="0" cellpadding="0" border="0">
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="EmployeeID">
							<br />
							<strong> 
              <xsl:choose>
                <xsl:when test="$lang = 'ru'">
                  Сотрудник:
                </xsl:when>
                <xsl:otherwise>
                  Employee:
                </xsl:otherwise>
              </xsl:choose>
            </strong>
							<xsl:value-of select="adf:GetListMember(EmployeeID, 'Employee', 'Name')"/>
						</xsl:when>
						<xsl:otherwise>	</xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="ProjectID">
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Проект:
                  </xsl:when>
                  <xsl:otherwise>
                    Project:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="adf:GetListMember(ProjectID, 'Project', 'Name')"/>
						</xsl:when>
						<xsl:otherwise>	</xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="ExpenseCodeID">
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Тип затрат:
                  </xsl:when>
                  <xsl:otherwise>
                    Expense Type:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="adf:GetListMember(ExpenseCodeID, 'ExpenseCode', 'Name')"/>
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="Date">
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Дата:
                  </xsl:when>
                  <xsl:otherwise>
                    Date:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="adf:FormatXmlDate(Date,'d')"/>
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>
				</td>
				<td>
					<xsl:choose>
						<xsl:when test="UOMID">
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Ед. измерения:
                  </xsl:when>
                  <xsl:otherwise>
                    Unit Of Measure:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="adf:GetListMember(UOMID, 'UOM', 'Name')"/>
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="Amount">
							<xsl:variable name="x" select="Amount"/>
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Количество:
                  </xsl:when>
                  <xsl:otherwise>
                    Amount:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="format-number($x,'0.##')"/>
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>
				</td>
				<td>
					<xsl:choose>
						<xsl:when test="Price">
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Цена:
                  </xsl:when>
                  <xsl:otherwise>
                    Price:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:variable name="x1" select="Price"/>
							<xsl:value-of select="format-number($x1,'0.##')"/>
							<xsl:text> </xsl:text>
							<xsl:value-of select="FromCurrencyCode"/>
						</xsl:when>
						<xsl:otherwise> </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="VATRate">
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Ставка НДС:
                  </xsl:when>
                  <xsl:otherwise>
                    VAT Rate:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:variable name="x4" select="VATRate"/>
							<xsl:value-of select="format-number($x4*100,'0.##')"/> %
						</xsl:when>
						<xsl:otherwise>	</xsl:otherwise>
					</xsl:choose>
				</td>
				<td>
					<xsl:choose>
						<xsl:when test="VAT">
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Сумма НДС:
                  </xsl:when>
                  <xsl:otherwise>
                    VAT Total:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:variable name="x5" select="VAT"/>
							<xsl:value-of select="format-number($x5,'0.##')"/>
							<xsl:text> </xsl:text>
							<xsl:value-of select="FromCurrencyCode"/>
						</xsl:when>
						<xsl:otherwise> </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="VATIsIncluded='true'">
							<br />
							<strong>
              <xsl:choose>
                <xsl:when test="$lang = 'ru'">
                  НДС включен:
                </xsl:when>
                <xsl:otherwise>
                  VAT Is Included:
                </xsl:otherwise>
              </xsl:choose>
            </strong>
              <xsl:choose>
                <xsl:when test="$lang = 'ru'">
                  да
                </xsl:when>
                <xsl:otherwise>
                  Yes
                </xsl:otherwise>
              </xsl:choose>
							<!--<input id="Checkbox1" checked="checked" type="checkbox" disabled="true" />-->
						</xsl:when>
						<xsl:otherwise>
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    НДС включен:
                  </xsl:when>
                  <xsl:otherwise>
                    VAT Is Included:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
              <xsl:choose>
                <xsl:when test="$lang = 'ru'">
                  нет
                </xsl:when>
                <xsl:otherwise>
                  No
                </xsl:otherwise>
              </xsl:choose>
							<!--<input id="Checkbox1" type="checkbox" disabled="true" />-->
						</xsl:otherwise>
					</xsl:choose>
				</td>
				<td>
					<xsl:choose>
						<xsl:when test="FromCurrencyCode">
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Валюта платежа:
                  </xsl:when>
                  <xsl:otherwise>
                    Payment Currency:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="FromCurrencyCode"/>
						</xsl:when>
						<xsl:otherwise>	</xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="$bcur!=$cur">
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Валюта проекта:
                  </xsl:when>
                  <xsl:otherwise>
                    Project Currency:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="ToCurrencyCode"/>
						</xsl:when>
					</xsl:choose>
				</td>
				<td>
					<xsl:if test="$cur">
						<xsl:if test="$bcur!=$cur">
							<xsl:choose>
								<xsl:when test="CurrencyRate">
									<xsl:choose>
										<xsl:when test="$ncur!=$cur">
											<br />
											<strong>
                        <xsl:choose>
                          <xsl:when test="$lang = 'ru'">
                            Курс валюты:
                          </xsl:when>
                          <xsl:otherwise>
                            Currency Rate
                          </xsl:otherwise>
                        </xsl:choose>
                      </strong>
											1 <xsl:value-of select="FromCurrencyCode"/> =
											<xsl:value-of select="format-number(CurrencyRate,'0.##')"/><xsl:text> </xsl:text> <xsl:value-of select="ToCurrencyCode"/>
										</xsl:when>
										<xsl:otherwise>
											<br />
											<strong>
                        <xsl:choose>
                          <xsl:when test="$lang = 'ru'">
                            Курс валюты:
                          </xsl:when>
                          <xsl:otherwise>
                            Currency Rate
                          </xsl:otherwise>
                        </xsl:choose>
                      </strong>
											1 <xsl:value-of select="ToCurrencyCode"/> =
											<xsl:value-of select="format-number(CurrencyRate,'0.##')"/><xsl:text> </xsl:text> <xsl:value-of select="FromCurrencyCode"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:when>
								<xsl:otherwise>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Курс <xsl:value-of select="FromCurrencyCode"/> к <xsl:value-of select="ToCurrencyCode"/> не указан
                    </xsl:when>
                    <xsl:otherwise>
                      Rate <xsl:value-of select="FromCurrencyCode"/> to <xsl:value-of select="ToCurrencyCode"/> is not defined
                    </xsl:otherwise>
                  </xsl:choose>
									
								</xsl:otherwise>
							</xsl:choose>
						</xsl:if>
					</xsl:if>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="VATIsIncluded='true'">
							<tr>
								<td>
									<br />
									<strong>
                    <xsl:choose>
                      <xsl:when test="$lang = 'ru'">
                        Сумма с НДС:
                      </xsl:when>
                      <xsl:otherwise>
                        Total With VAT:
                      </xsl:otherwise>
                    </xsl:choose>
                  </strong>
									<xsl:variable name="SumNDS" select="$price*$amount"/>
									<xsl:value-of select="format-number($SumNDS,'0.##')"/>
									<xsl:text> </xsl:text>
									<xsl:value-of select="FromCurrencyCode"/>
								</td>
								<td>
									<br />
									<strong>
                    <xsl:choose>
                      <xsl:when test="$lang = 'ru'">
                        Сумма без НДС:
                      </xsl:when>
                      <xsl:otherwise>
                        Total Without VAT:
                      </xsl:otherwise>
                    </xsl:choose>
                  </strong>
									<xsl:variable name="SumWONDS" select="$price*$amount - $vat"/>
									<xsl:value-of select="format-number($SumWONDS,'0.##')"/>
									<xsl:text> </xsl:text>
									<xsl:value-of select="FromCurrencyCode"/>
								</td>
							</tr>
							<xsl:choose>
								<xsl:when test="$bcur!=$cur">
									<tr>
										<td>
											<xsl:choose>
												<xsl:when test="CurrencyRate">
													<br />
													<strong>
                            <xsl:choose>
                              <xsl:when test="$lang = 'ru'">
                                Сумма в валюте проекта без НДС:
                              </xsl:when>
                              <xsl:otherwise>
                                Total in project currency Without VAT:
                              </xsl:otherwise>
                            </xsl:choose>
                          </strong>
													<xsl:value-of select="format-number(TotalPC,'0.##')"/>
													<xsl:text> </xsl:text>
													<xsl:value-of select="ToCurrencyCode"/>
												</xsl:when>
												<xsl:otherwise>
													<br />
                          <xsl:choose>
                            <xsl:when test="$lang = 'ru'">
                              Сумма в валюте проекта не определена
                            </xsl:when>
                            <xsl:otherwise>
                              Total in project currency is not defined
                            </xsl:otherwise>
                          </xsl:choose>
												</xsl:otherwise>
											</xsl:choose>
										</td>
										<td>
											<xsl:choose>
												<xsl:when test="CurrencyRate">
													<br />
													<strong>
                            <xsl:choose>
                              <xsl:when test="$lang = 'ru'">
                                Сумма в валюте проекта с НДС:
                              </xsl:when>
                              <xsl:otherwise>
                                Total in project currency With VAT:
                              </xsl:otherwise>
                            </xsl:choose>
                          </strong>
													<xsl:value-of select="format-number(TotalWithVATPC ,'0.##')"/>
													<xsl:text> </xsl:text>
													<xsl:value-of select="ToCurrencyCode"/>
												</xsl:when>
											</xsl:choose>
										</td>
									</tr>
								</xsl:when>
							</xsl:choose>
						</xsl:when>
					</xsl:choose>
				</td>
			</tr>

			<xsl:choose>
				<xsl:when test="VATIsIncluded='false'">
					<tr>
						<td>
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Сумма с НДС:
                  </xsl:when>
                  <xsl:otherwise>
                    Total With VAT:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:variable name="SumNDS" select="$price*$amount+$vat"/>
							<xsl:value-of select="format-number($SumNDS,'0.##')"/>
						</td>
						<td>
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Сумма без НДС:
                  </xsl:when>
                  <xsl:otherwise>
                    Total Without VAT:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:variable name="SumWONDS" select="$price*$amount"/>
							<xsl:value-of select="format-number($SumWONDS,'0.##')"/>
						</td>
					</tr>
					<xsl:choose>
						<xsl:when test="$bcur!=$cur">

							<tr>
								<td>
									<xsl:choose>
										<xsl:when test="CurrencyRate">
											<br />
											<strong>
                        <xsl:choose>
                          <xsl:when test="$lang = 'ru'">
                            Сумма в валюте проекта без НДС:
                          </xsl:when>
                          <xsl:otherwise>
                            Total in project currency Without VAT:
                          </xsl:otherwise>
                        </xsl:choose>
                      </strong>
											<xsl:variable name="totalpc" select="TotalPC"/>
											<xsl:variable name="SumWONDS" select="$price*$amount"/>
											<xsl:variable name="real" select="round((round($SumWONDS*$cr1*100) div 100) div $amount*100) div 100 * $amount"/>
											<xsl:value-of select="format-number($real ,'0.##')"/>
											<xsl:text> </xsl:text>
											<xsl:value-of select="FromCurrencyCode"/>
										</xsl:when>

										<xsl:otherwise>
											<br />
                      <xsl:choose>
                        <xsl:when test="$lang = 'ru'">
                          Сумма в валюте проекта не определена
                        </xsl:when>
                        <xsl:otherwise>
                          Total in project currency is not defined
                        </xsl:otherwise>
                      </xsl:choose>
										</xsl:otherwise>
									</xsl:choose>
								</td>
								<td>
									<xsl:choose>
										<xsl:when test="CurrencyRate">
											<br />
											<strong>
                        <xsl:choose>
                          <xsl:when test="$lang = 'ru'">
                            Сумма в валюте проекта с НДС:
                          </xsl:when>
                          <xsl:otherwise>
                            Total in project currency With VAT:
                          </xsl:otherwise>
                        </xsl:choose>
                      </strong>
											<xsl:variable name="totalwpc" select="TotalWithVATPC"/>
											<xsl:variable name="SumWONDS" select="$price*$amount"/>
											<xsl:variable name="totalpc" select="TotalPC"/>
											<xsl:variable name="real" select="round((round($SumWONDS*$cr1*100) div 100) div $amount*100) div 100 * $amount"/>
											<xsl:value-of select="format-number(round($real*(1+$vatr)*100) div 100,'0.##')"/>
											<xsl:text> </xsl:text>
											<xsl:value-of select="FromCurrencyCode"/>
										</xsl:when>
									</xsl:choose>
								</td>
							</tr>
						</xsl:when>
					</xsl:choose>
				</xsl:when>
			</xsl:choose>

			<tr>
				<td>
					<br />
					<strong>
            <xsl:choose>
              <xsl:when test="$lang = 'ru'">
                К оплате:
              </xsl:when>
              <xsl:otherwise>
                Billable:
              </xsl:otherwise>
            </xsl:choose>
          </strong>
					<xsl:choose>
						<xsl:when test="Billable='true'">
							<!--<input id="Checkbox2" checked="checked" type="checkbox" disabled="true" />-->
              <xsl:choose>
                <xsl:when test="$lang = 'ru'">
                  да
                </xsl:when>
                <xsl:otherwise>
                  Yes
                </xsl:otherwise>
              </xsl:choose>
						</xsl:when>
					</xsl:choose>
					<xsl:choose>
						<xsl:when test="Billable='false'">
							<!--<input id="Checkbox2" type="checkbox" disabled="false" />-->
              <xsl:choose>
                <xsl:when test="$lang = 'ru'">
                  нет
                </xsl:when>
                <xsl:otherwise>
                  No
                </xsl:otherwise>
              </xsl:choose>
						</xsl:when>
					</xsl:choose>
				</td>
			</tr>



		</table>

	</xsl:template>
</xsl:stylesheet>