<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:adf="urn:avicomsys-ru:adf-preview">
  <xsl:variable name="lang" select="adf:GetLanguage()" />
  <xsl:template match="/">
    <HTML>
      <HEAD>
        <TITLE>
          <xsl:value-of select="pjm5InvoiceGet/Invoice/FileAs" />
        </TITLE>
        <xsl:value-of select="adf:GetCss()" disable-output-escaping="yes" />
      </HEAD>
      <BODY >
        <xsl:value-of select="adf:GetHeader(pjm5InvoiceGet/Invoice)"  disable-output-escaping="yes"/>
        <xsl:apply-templates select="//Invoice"/>
        <br />
        <xsl:choose>
          <xsl:when test="//Line/ID">

            <table border="1" cellspacing="0" cellpadding="4">
              <tr>
                <th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Описание
                    </xsl:when>
                    <xsl:otherwise>
                      Description
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
                <th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Количество
                    </xsl:when>
                    <xsl:otherwise>
                      Amount
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
                <th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Ед.измерения
                    </xsl:when>
                    <xsl:otherwise>
                      Unit Of Measure
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
                <th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Цена
                    </xsl:when>
                    <xsl:otherwise>
                      Price
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
                <th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      НДС
                    </xsl:when>
                    <xsl:otherwise>
                      VAT
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
                <th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Сумма
                    </xsl:when>
                    <xsl:otherwise>
                      Total
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
                <th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Валюта
                    </xsl:when>
                    <xsl:otherwise>
                      Currency
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
              </tr>
              <xsl:for-each select="//Line">
                <xsl:apply-templates select="."/>
              </xsl:for-each>
            </table>

          </xsl:when>
          <xsl:otherwise>	</xsl:otherwise>
        </xsl:choose>

        <xsl:value-of select="adf:GetFooter(pjm5InvoiceGet/Invoice)"  disable-output-escaping="yes"/>

      </BODY>
    </HTML>
  </xsl:template>

  <xsl:template match="Line">
    <tr>
      <td>
        <xsl:value-of select="Description"/>
      </td>
      <td align="right">
        <xsl:variable name="u" select="Amount"/>
        <xsl:value-of select="format-number($u,'0.##')"/>
      </td>
      <td>
        <xsl:value-of select="UOM"/>
      </td>
      <td align="right">
        <xsl:variable name="z" select="PriceWithVAT"/>
        <xsl:value-of select="format-number($z,'0.##')"/>
      </td>
      <td align="right">
        <xsl:variable name="t" select="VAT"/>
        <xsl:value-of select="format-number($t,'0.##')"/>
      </td>
      <td align="right">
        <xsl:variable name="z1" select="SumWithVAT"/>
        <xsl:value-of select="format-number($z1,'0.##')"/>
      </td>
      <td>
        <xsl:apply-templates select="//Invoice/CurrencyCode"/>
      </td>
    </tr>
  </xsl:template>

  <xsl:template match="CurrencyCode">


    <xsl:value-of select="."/>
  </xsl:template>
  <xsl:template match="Invoice">
    <xsl:variable name="cur" select="CurrencyCode"></xsl:variable>
    <xsl:variable name="bcur" select="ProjectCurrencyCode"></xsl:variable>

    <table style="font-family:Verdana;font-size:8pt" cellspacing="0" cellpadding="0" border="0">

      <tr>
        <td>
          <xsl:choose>
            <xsl:when test="Date">
              <br/>
              <strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Дата:
                  </xsl:when>
                  <xsl:otherwise>
                    Date:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
              <xsl:value-of select="adf:FormatXmlDate(Date,'d')"/>
            </xsl:when>
            <xsl:otherwise>	 </xsl:otherwise>
          </xsl:choose>
        </td>
      </tr>
      <tr>
        <td>
          <xsl:choose>
            <xsl:when test="ContractNumber">
              <br />
              <strong> 
              <xsl:choose>
                <xsl:when test="$lang = 'ru'">
                  Договор:
                </xsl:when>
                <xsl:otherwise>
                  Project Code:
                </xsl:otherwise>
              </xsl:choose>
            </strong>
              <xsl:value-of select="ContractNumber"/>
            </xsl:when>
            <xsl:otherwise>	 </xsl:otherwise>
          </xsl:choose>
        </td>
      </tr>
      <tr>
        <td>
          <xsl:choose>
            <xsl:when test="CustomerCompanyID">
              <br/>
              <strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Покупатель:
                  </xsl:when>
                  <xsl:otherwise>
                    Customer:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
              <xsl:value-of select="adf:GetListMember(CustomerCompanyID, 'Company', 'Name')"/>
            </xsl:when>
            <xsl:otherwise>	 </xsl:otherwise>
          </xsl:choose>
        </td>
      </tr>
      <tr>
        <td>
          <xsl:choose>
            <xsl:when test="SupplierCompanyID">
              <br/>
              <strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Поставщик:
                  </xsl:when>
                  <xsl:otherwise>
                    Supplier:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
              <xsl:value-of select="adf:GetListMember(SupplierCompanyID, 'Company', 'Name')"/>
            </xsl:when>
            <xsl:otherwise>	 </xsl:otherwise>
          </xsl:choose>
        </td>
      </tr>
      <tr>
        <td>
          <xsl:choose>
            <xsl:when test="SupplierBankAccountID">
              <br/>
              <strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Расчетный счет:
                  </xsl:when>
                  <xsl:otherwise>
                    Bank Account:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
              <xsl:value-of select="adf:GetListMember(SupplierBankAccountID, 'BankAccount', 'Name')"/>
            </xsl:when>
            <xsl:otherwise> </xsl:otherwise>
          </xsl:choose>
        </td>
      </tr>
      <tr>
        <td>
          <xsl:choose>
            <xsl:when test="TotalWithVAT">
              <br />
              <strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Сумма:
                  </xsl:when>
                  <xsl:otherwise>
                    Total:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
              <xsl:variable name="x" select="TotalWithVAT"/>
              <xsl:value-of select="format-number($x,'0.##')"/>
            </xsl:when>
            <xsl:otherwise>	 </xsl:otherwise>
          </xsl:choose>
        </td>
      </tr>
      <tr>
        <td>
          <xsl:choose>
            <xsl:when test="TotalWithVATPC">
              <br />
              <strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    В валюте проекта:
                  </xsl:when>
                  <xsl:otherwise>
                    To Project Currency:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
              <xsl:variable name="y" select="TotalWithVATPC"/>
              <xsl:value-of select="format-number($y,'0.##')"/>
            </xsl:when>
            <xsl:otherwise>	 </xsl:otherwise>
          </xsl:choose>
        </td>
      </tr>
      <tr>
        <td>
          <xsl:choose>
            <xsl:when test="CurrencyCode">
              <br />
              <strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Валюта платежа:
                  </xsl:when>
                  <xsl:otherwise>
                    Payment Currency:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
              <xsl:value-of select="CurrencyCode"/>
            </xsl:when>
            <xsl:otherwise>	</xsl:otherwise>
          </xsl:choose>
        </td>
      </tr>
      <tr>
        <td>
          <xsl:choose>
            <xsl:when test="ProjectCurrencyCode">
              <br />
              <strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Валюта проекта:
                  </xsl:when>
                  <xsl:otherwise>
                    Project Currency:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
              <xsl:value-of select="ProjectCurrencyCode"/>
            </xsl:when>
            <xsl:otherwise>	</xsl:otherwise>
          </xsl:choose>
        </td>
      </tr>
      <tr>
        <td>
          <xsl:if test="$cur">
            <xsl:if test="$bcur!=$cur">
              <xsl:choose>
                <xsl:when test="CurrencyRate">
                  <br />
                  <strong>
                    <xsl:choose>
                      <xsl:when test="$lang = 'ru'">
                        Курс валюты:
                      </xsl:when>
                      <xsl:otherwise>
                        Currency Rate:
                      </xsl:otherwise>
                    </xsl:choose>
                  </strong>
                  1 <xsl:value-of select="CurrencyCode"/> = <xsl:variable name="cr" select="CurrencyRate"/> <xsl:value-of select="format-number($cr,'0.##')"/><xsl:text> </xsl:text> <xsl:value-of select="ProjectCurrencyCode"/>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Курс <xsl:value-of select="CurrencyCode"/> к <xsl:value-of select="ProjectCurrencyCode"/> не указан
                    </xsl:when>
                    <xsl:otherwise>
                      Rate  <xsl:value-of select="CurrencyCode"/> to <xsl:value-of select="ProjectCurrencyCode"/> is not defined
                    </xsl:otherwise>
                  </xsl:choose>
                 
                </xsl:otherwise>
              </xsl:choose>
            </xsl:if>
          </xsl:if>
        </td>
      </tr>
    </table>
  </xsl:template>
</xsl:stylesheet>