<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:adf="urn:avicomsys-ru:adf-preview">
  <xsl:variable name="lang" select="adf:GetLanguage()" />
  <xsl:template match="/">
    <HTML>
      <HEAD>
        <TITLE>
          <xsl:value-of select="pjm5ServiceGet/Service/FileAs" />
        </TITLE>
        <xsl:value-of select="adf:GetCss()" disable-output-escaping="yes" />

      </HEAD>
      <BODY >
        <xsl:value-of select="adf:GetHeader(pjm5ServiceGet/Service)"  disable-output-escaping="yes"/>
        <xsl:apply-templates select="//Service"/>

        <xsl:choose>
          <xsl:when test="//ServicePrice/PriceWOVAT">
            <table style="font-family:Verdana;font-size:8pt" cellspacing="0" cellpadding="0" border="0">
              <tr>
                <td>
                  <br />
                  <strong>
                    <xsl:choose>
                      <xsl:when test="$lang = 'ru'">
                        Цена услуги в различных валютах:
                      </xsl:when>
                      <xsl:otherwise>
                        Service prices
                      </xsl:otherwise>
                    </xsl:choose>
                  </strong>
                </td>
              </tr>
            </table>
            <br />
            <table border="1" cellspacing="0" cellpadding="4">
              <tr>
                <th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Цена (без НДС)
                    </xsl:when>
                    <xsl:otherwise>
                      Price Without VAT
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
                <th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      НДС
                    </xsl:when>
                    <xsl:otherwise>
                      VAT
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
                <th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Цена (с НДС)
                    </xsl:when>
                    <xsl:otherwise>
                      Price With VAT
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
                <th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Валюта
                    </xsl:when>
                    <xsl:otherwise>
                      Currency
                    </xsl:otherwise>
                  </xsl:choose>
                </th>

              </tr>
              <xsl:for-each select="//ServicePrice">
                <xsl:apply-templates select="."/>
              </xsl:for-each>
            </table>

          </xsl:when>
          <xsl:otherwise>	</xsl:otherwise>
        </xsl:choose>

        <xsl:value-of select="adf:GetFooter(pjm5ServiceGet/Service)"  disable-output-escaping="yes"/>

      </BODY>
    </HTML>
  </xsl:template>

  <xsl:template match="Service">
    <table style="font-family:Verdana;font-size:8pt" cellspacing="0" cellpadding="0" border="0">
      <tr>
        <td>
          <xsl:choose>
            <xsl:when test="ServiceTypeID">
              <br />
              <strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Тип:
                  </xsl:when>
                  <xsl:otherwise>
                    Type:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
              <xsl:value-of select="adf:GetListMember(ServiceTypeID, 'ServiceType', 'Name')"/>
            </xsl:when>
            <xsl:otherwise>	 </xsl:otherwise>
          </xsl:choose>
        </td>
      </tr>
      <tr>
        <td>
          <xsl:choose>
            <xsl:when test="PaymentTermID">
              <br />
              <strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Способ оплаты:
                  </xsl:when>
                  <xsl:otherwise>
                    Payment Term:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
              <xsl:value-of select="adf:GetListMember(PaymentTermID, 'PaymentTerm', 'Name')"/>
            </xsl:when>
            <xsl:otherwise>	 </xsl:otherwise>
          </xsl:choose>
        </td>
      </tr>
      <table style="font-family:Verdana;font-size:8pt" cellspacing="0" cellpadding="0" border="0">

        <tr>
          <td>
            <xsl:choose>
              <xsl:when test="UOMID">
                <br/>
                <strong>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Ед. измерения:
                    </xsl:when>
                    <xsl:otherwise>
                      Unit Of Measure:
                    </xsl:otherwise>
                  </xsl:choose>
                </strong>
                <xsl:value-of select="adf:GetListMember(UOMID, 'UOM', 'Code')"/>
              </xsl:when>
              <xsl:otherwise>	 </xsl:otherwise>
            </xsl:choose>
          </td>
        </tr>
        <tr>
          <td>
            <br />
            <strong>
              <xsl:choose>
                <xsl:when test="$lang = 'ru'">
                  Цены указаны с НДС:
                </xsl:when>
                <xsl:otherwise>
                  Prices are with VAT:
                </xsl:otherwise>
              </xsl:choose>
            </strong>
            <xsl:choose>
              <xsl:when test="VATIsIncluded='true'">
                <input id="Checkbox1" checked="checked" type="checkbox" disabled="true" />
              </xsl:when>
            </xsl:choose>
            <xsl:choose>
              <xsl:when test="VATIsIncluded='false'">
                <input id="Checkbox1" type="checkbox" disabled="false" />
              </xsl:when>
            </xsl:choose>
          </td>
        </tr>
      </table>
    </table>
  </xsl:template>


  <xsl:template match="ServicePrice">
    <tr>
      <td align="right">
        <xsl:variable name="x" select="PriceWOVAT"/>
        <xsl:value-of select="format-number($x,'0.##')"/>
      </td>
      <td align="right">
        <xsl:variable name="y" select="VAT"/>
        <xsl:value-of select="format-number($y,'0.##')"/>
      </td>
      <td align="right">
        <xsl:variable name="z" select="PriceWithVAT"/>
        <xsl:value-of select="format-number($z,'0.##')"/>
      </td>
      <td>
        <xsl:value-of select="CurrencyCode"/>
      </td>
    </tr>
  </xsl:template>


</xsl:stylesheet>